Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1461)

Unified Diff: pydir/run-pnacl-sz.py

Issue 956123002: Subzero: Change the name llvm2ice to the more appropriate pnacl-sz. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Make comment correct Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« README.rst ('K') | « pydir/run-llvm2ice.py ('k') | pydir/szbuild.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pydir/run-pnacl-sz.py
diff --git a/pydir/run-llvm2ice.py b/pydir/run-pnacl-sz.py
similarity index 96%
rename from pydir/run-llvm2ice.py
rename to pydir/run-pnacl-sz.py
index 31535b85a900b1bf8d242ddbd04f558dcfd15b53..65eb22bf70c10436f9b2b7eba409240c6354ee48 100755
--- a/pydir/run-llvm2ice.py
+++ b/pydir/run-pnacl-sz.py
@@ -11,7 +11,7 @@ import tempfile
from utils import shellcmd
def main():
"""Run the llvm2ice compiler on an llvm file.
Takes an llvm input file, freezes it into a pexe file, converts
it to a Subzero program, and finally compiles it.
@@ -38,8 +38,8 @@ def main():
'(without generating a pexe), then ' +
'convert to Subzero')
argparser.add_argument(
- '--llvm2ice', required=False, default='./llvm2ice', metavar='LLVM2ICE',
- help="Subzero translator 'llvm2ice'")
+ '--pnacl-sz', required=False, default='./pnacl-sz', metavar='PNACL-SZ',
+ help="Subzero translator 'pnacl-sz'")
argparser.add_argument('--llvm-bin-path', required=False,
default=None, metavar='LLVM_BIN_PATH',
help='Path to LLVM executables ' +
@@ -64,7 +64,7 @@ def main():
help='Trace command that generates ICE instructions')
argparser.add_argument('--args', '-a', nargs=argparse.REMAINDER,
default=[],
- help='Remaining arguments are passed to llvm2ice')
+ help='Remaining arguments are passed to pnacl-sz')
args = argparser.parse_args()
llvm_bin_path = args.llvm_bin_path
@@ -85,7 +85,7 @@ def main():
if not args.no_local_syms:
cmd += ['--allow-local-symbol-tables']
cmd += ['|']
- cmd += [args.llvm2ice]
+ cmd += [args.pnacl_sz]
if args.insts:
# If the tests are based on '-verbose inst' output, force
# single-threaded translation because dump output does not get
@@ -11,7 +11,7 @@ import tempfile
from utils import shellcmd
def main():
- """Run the llvm2ice compiler on an llvm file.
+ """Run the pnacl-sz compiler on an llvm file.
Takes an llvm input file, freezes it into a pexe file, converts
it to a Subzero program, and finally compiles it.
« README.rst ('K') | « pydir/run-llvm2ice.py ('k') | pydir/szbuild.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698